pm4py.algo.conformance.alignments.edit\_distance package
========================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.alignments.edit_distance.variants

Submodules
----------

pm4py.algo.conformance.alignments.edit\_distance.algorithm module
-----------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.edit_distance.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.edit_distance
   :members:
   :undoc-members:
   :show-inheritance:
